'=====================================================
' NAME:    OM12AgentInstall.vbs
' AUTHOR:  Tao Yang 
' DATE:    14/05/2014
' Version 1.0.0.0
' COMMENT: OpsMgr 2012 R2 agent installation with UR2
'          Used for CM12 Application deployment types
'=====================================================
Option Explicit
'ON ERROR RESUME NEXT

'Define variables
Dim oArgs, OSArch, LogFile, LogFilePath
Dim strInstallCmd, InstallResult, sh, strUpdateCmd, UpdateResult
Dim strPWD, objFSO, TempDir, strUnknownOSArchMsg

Const ForWriting = 2
Const ForAppending = 3

'process arguments
Set sh = Wscript.CreateObject("Wscript.Shell")
Set oArgs = Wscript.Arguments

IF oArgs.Count < 1 THEN
	'Quit if no arguments passed in
	Wscript.Quit -1
ELSE
	OSArch = oArgs(0)
END IF

Set objFSO = CreateObject("Scripting.FileSystemObject")
TempDir = "C:\Temp"

If objFSO.FolderExists(TempDir) = FALSE Then
	objFSO.CreateFolder(TempDir)
End If

LogFilePath = TempDir & "\OM12AgentInstall.log"

'delete previous log file
If objFSO.FileExists(LogFilePath) Then
   objFSO.DeleteFile(LogFilePath)
End If

'Create log file
Set LogFile = objFSO.CreateTextFile(LogFilePath, True)

LogFile.WriteLine "OM12AgentInstall.vbs version: 1.0.0.0"

'Set LogFile = objFSO.OpenTextFile(LogFilePath, ForWriting, True)

strPWD = CreateObject("Scripting.FileSystemObject").GetAbsolutePathName(".")

LogFile.WriteLine "OS Architecture: " & OSArch
'Prepare the agent install command
IF LCase(OSArch) = "64-bit" THEN
	strInstallCmd = "msiexec /i " & CHR(34) & strPWD & "\AMD64\MOMAgent.msi" & CHR(34) & " /qn AcceptEndUserLicenseAgreement=1 /l*v " & TempDir & "\OM12AgentMSI.log"
	LogFile.WriteLine "64 bit OS detected. Installing OM12 R2 agent using command: '" & strInstallCmd & "'"
	strUpdateCmd = "msiexec /update " & CHR(34) & strPWD & "\AMD64\KB2929891-amd64-Agent.msp" & CHR(34) & " /qn AcceptEndUserLicenseAgreement=1 /l*v " & TempDir & "\OM12AgentUR2Update.log"
	LogFile.WriteLine "Installing OM12 R2 agent UR2 update using command: '" & strUpdateCmd & "'"
ELSEIF LCase(OSArch) = "32-bit" THEN
	strInstallCmd = "msiexec /i " & CHR(34) & strPWD & "\i386\MOMAgent.msi" & CHR(34) & " /qn AcceptEndUserLicenseAgreement=1 /l*v " & TempDir & "\OM12AgentMSI.log"
	LogFile.WriteLine "32 bit OS detected. Installing OM12 R2 agent using command: '" & strInstallCmd & "'"
	strUpdateCmd = "msiexec /update " & CHR(34) & strPWD & "\i386\KB2929891-i386-Agent.msp" & CHR(34) & " /qn AcceptEndUserLicenseAgreement=1 /l*v " & TempDir & "\OM12AgentUR2Update.log"
	LogFile.WriteLine "Installing OM12 R2 agent UR2 update using command: '" & strUpdateCmd & "'"
ELSE
	strUnknownOSArchMsg = "Error: Unknown OS Architecture specified in the argument. Expecting '64-bit' or '32-bit'. the value passed in is '" & OSArch & "'. Installation Aborted."
	Wscript.Echo strUnknownOSArchMsg
	LogFile.WriteLine strUnknownOSArchMsg
	Wscript.Quit -1
END IF

'Install agent
Wscript.Echo "Installing SCOM 2012 R2 Agent With UR2 Update..."
InstallResult = sh.run(strInstallCmd,0,True)
If InstallResult <> 0 Then
	LogFile.WriteLine "Failed to install OM12 R2 agent."
	LogFile.Close
	Wscript.Quit -1
Else
	LogFile.WriteLine "Successfully installed the OM12 R2 agent."
End if

'Update agent
UpdateResult = sh.run(strUpdateCmd,0,True)
If UpdateResult <> 0 Then
	LogFile.WriteLine "Failed to install OM12 R2 agent UR2 update."
	LogFile.Close
	Wscript.Quit -1
Else
	LogFile.WriteLine "Successfully installed the OM12 R2 agent UR2 update."
End if

LogFile.WriteLine "Done."
LogFile.Close
